==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerStatusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertmanagerStatusBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusBuilder>{
  public AlertmanagerStatusBuilder() {
    this(false);
  }
  public AlertmanagerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertmanagerStatus(), validationEnabled);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertmanagerStatus(), validationEnabled);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withPaused(instance.getPaused()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withUnavailableReplicas(instance.getUnavailableReplicas()); 
    fluent.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance) {
    this(instance,false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withPaused(instance.getPaused()); 
    this.withReplicas(instance.getReplicas()); 
    this.withUnavailableReplicas(instance.getUnavailableReplicas()); 
    this.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus build() {
    AlertmanagerStatus buildable = new AlertmanagerStatus(fluent.getAvailableReplicas(),fluent.getPaused(),fluent.getReplicas(),fluent.getUnavailableReplicas(),fluent.getUpdatedReplicas());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerStatusBuilder that = (AlertmanagerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerStatusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertmanagerStatusBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusBuilder>{
  public AlertmanagerStatusBuilder() {
    this(false);
  }
  public AlertmanagerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertmanagerStatus(), validationEnabled);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertmanagerStatus(), validationEnabled);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withPaused(instance.getPaused()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withUnavailableReplicas(instance.getUnavailableReplicas()); 
    fluent.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance) {
    this(instance,false);
  }
  public AlertmanagerStatusBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withPaused(instance.getPaused()); 
    this.withReplicas(instance.getReplicas()); 
    this.withUnavailableReplicas(instance.getUnavailableReplicas()); 
    this.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerStatus build() {
    AlertmanagerStatus buildable = new AlertmanagerStatus(fluent.getAvailableReplicas(),fluent.getPaused(),fluent.getReplicas(),fluent.getUnavailableReplicas(),fluent.getUpdatedReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerStatusBuilder that = (AlertmanagerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
